
"""
    Title: reset.py
    Module Name: reset.py
    Author: Akash Dwivedi
    Language: Python
    Date Created: 26-07-2021
    Date Modified: 29-07-2021
    Description:
        ###############################################################
        ## Reset/ rollback function     ## 
         ###############################################################
 """
import git
import os
import click
import git
import sys
from github import Github


@click.command()
@click.option('--token', '-e', default="dev", prompt='Enter token ', help='Roll back to the previous version')
def reset(token):
  """Roll back to the previous version"""
    
  """
    param : token is the argument which is a aceess token for getting access to the
    github repository.
    Variables Used:
    token : Stores the github access token 
    repo : stores the reposirory 
    
    return: Nil
  """
  g=Github(token)
  name=input("Enter the repo name")
  repo_name="AkashAi7/"+name
  repo = git.Repo(repo_name)
  repo.git.reset('--hard')



"""
    Title: auth.py
    Module Name: auth.py
    Author: Akash Dwivedi
    Language: Python
    Date Created: 26-07-2021
    Date Modified: 29-07-2021
    Description:
        ###############################################################
        ## Authenticate the user account    ## 
         ###############################################################
 """
import git
import os
import click
import git
import sys
from github import Github


@click.command()
@click.option('--token', '-e', default="dev", prompt='Enter token ', help='Token for authentiication')
def auth(token):
    """Authenticate your self"""
    token="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"
    
    tk1=token
    g=Github(token)
    click.echo(f"Your Token is  {g}!")
    click.echo(f"Your Token is  {token}!")
    repo(tk1)
    

def repo(tk1):
   tk2=tk1
   g=Github(str(tk1))
   print(g)
   i=1
   for repo in g.get_user().get_repos():
    print(i," ",repo.name)
    i=i+1
   




"""
    Title: allrepo.py
    Module Name: allrepo.py
    Author: Akash Dwivedi
    Language: Python
    Date Created: 26-07-2021
    Date Modified: 29-07-2021
    Description:
        ###############################################################
        ## Display Avaialable Reposirot   ## 
         ###############################################################
 """
import git
import os
import click
import git
import sys
from github import Github


@click.command()
@click.option('--token', '-e', default="dev", prompt='Enter token ', help='Shows all the repo in the account')
def allrepo(token):
    '''Shows all the repo in the account '''
    """
    param : token is the argument which is a aceess token for getting access to the
    github repository.
    Variables Used:
    token : Stores the github access token 
    repo : stores the reposirory 
    
    return: Nil
    """
    print('Choose the repo type ')
    g=Github(token)
    print(g)
    i=1
    for repo in g.get_user().get_repos():
     print(i," ",repo.name)
     i=i+1



import git
import os
import click
import sys
from wsgiref.simple_server import make_server
from pyramid.config import Configurator
from pyramid.view import view_config, view_defaults
from pyramid.response import Response
from github import Github
ENDPOINT = "webhook"


@view_defaults(
    route_name=ENDPOINT, renderer="json", request_method="POST"
)
class PayloadView():
    # this class will called automatically when webhook will be created successfully on a repository

    def __init__(self, request):
        self.request = request
        self.payload = self.request.json

    # This method will be called when webhook will be created successfully on a repository
    @view_config(header="X-GitHub-Event:ping")
    def payload_ping(self):
        print("Pinged! Webhook created with id {}!".format(self.payload["hook_id"]))
        return {"status": 200}

    # This method will be called when an particular push event will be triggered on an repository
    @view_config(header="X-Github-Event:push")
    def payload_push(self):
        print("No. of commits in push: ", len(self.payload['commits']))
        print("commit msg", self.payload["commits"][0]["message"])
        print("commit added", self.payload["commits"][0]["added"])
        return Response("success")

    # This method will be called when an pull request will be happen on a repository
    @view_config(header="X-GitHub-Event:pull_request")
    def payload_pull_request(self):
        print("pull request = ", self.payload['action'])
        print("commits in pull: ", self.payload['pull_request'])
        return Response("success")
        


# create webhook on a particular repo
@click.command()
@click.option('--token', '-e', default="dev", prompt='Enter token ', help='Enter token')
@click.option('--username', '-e', default="dev", prompt='Enter user name ', help='Enter the username of ')
@click.option('--hostname', '-e', default="dev", prompt='Enter host ', help='Enter the host ip  ')
@click.option('--reponame', '-e', default="dev", prompt='Enter repo ', help='Enter the reponame ')
def create_webhook(token,username,hostname,reponame):
    access_token = token
    OWNER = username# github account name
    REPO_NAME = reponame# github repository name
    EVENTS = ["*"]      # Events on github
    HOST = hostname  # ngrok tunnel

    config = {
        "url": "http://{host}/{endpoint}".format(host=HOST, endpoint=ENDPOINT),
        "content_type": "json"
    }

     # login to github account
    g = Github(access_token)

    # accessing a particular repository of a account
    repo = g.get_repo("{owner}/{repo_name}".format(owner=OWNER, repo_name=REPO_NAME))
    print(repo)

    # creating a webhook on a particular repository
    repo.create_hook("web", config, EVENTS, active=True)

   


if __name__ == "__main__":
    config = Configurator()

    config.add_route(ENDPOINT, "/{}".format(ENDPOINT))
    config.scan()

    app = config.make_wsgi_app()
    server = make_server("localhost", 80, app)
    create_webhook()
    server.serve_forever()






#setup.py

"""
    Title: setup.py
    Module Name: setup.py
    Author: Akash Dwivedi
    Language: Python
    Date Created: 26-07-2021
    Date Modified: 29-07-2021
    Description:
        ###############################################################
        ## Setup.py file for the package      ## 
         ###############################################################
 """
from setuptools import _install_setup_requires, setup,find_packages

with open('requirements.txt') as f:
    required = f.read().splitlines()
setup(
    name='buildpan',
    version='0.0.7',
    packages=find_packages(),
    install_requires=required,
    entry_points={
        'console_scripts': [
            'buildpan =buildpan.buildpan:buildpan'
        ]
    }
)



"""
    Title: selectrepo.py
    Module Name: allrepo.py
    Author: Akash Dwivedi
    Language: Python
    Date Created: 26-07-2021
    Date Modified: 29-07-2021
    Description:
        ###############################################################
        ## Selects a specific repository   ## 
         ###############################################################
 """
import git
import os
import click
import git
import sys
from github import Github


@click.command()
@click.option('--token', '-e', default="dev", prompt='Enter token ', help='Shows all the repo in the account')

def selectrepo(token):
    '''Select the repo in the account '''
    """
    param : token is the argument which is a aceess token for getting access to the
    github repository.
    Variables Used:
    token : Stores the github access token 
    repo : stores the reposirory 
    content: Stores the files avaialable in the files in the repository
    return: Nil
    """
    g=Github(token)
    print(g)
    i=1
    for repo in g.get_user().get_repos():
     print(i," ",repo.name)
    i=i+1
    name=input("Enter the repo name")
    repo=g.get_repo("AkashAi7/"+name)
    reponame="AkashAi7/"+name
    print(reponame)
    content=repo.get_contents("")
    for file in content:
       print("FILE NAME ARE ",file)
   